/*
 * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
 *
 */

#ifndef AUDIOJSON_H
#define AUDIOJSON_H

#include <QDebug>
#include <QFile>
#include <qjsondocument.h>
#include <qjsonobject.h>
#include <qbytearray.h>
#include <qstring.h>
#include <QSettings>
#include <QObject>
#include <syslog.h>

#define DEFAULT_AUDIO_DEV "default"

class UserConf : public QObject
{
    Q_OBJECT

public:
    UserConf(QObject *parent = nullptr);
    ~UserConf();

    QJsonValue readJson(QString username, QString jsonFile, QString key);
    void insertJson();

    QString readLightdmConf();
    QString readLastUser();

    // 配置文件对象
    QSettings *settings;
};

#endif // AUDIOJSON_H
